@@ -12,16 +12,18 @@ pub enum SuErr {
 #[cfg(feature = "pyo3")]
 mod pysupport {
     use super::*;
-    use pyo3::PyErr;
     use pyo3::exceptions::{PyOverflowError, PyTypeError};
+    use pyo3::PyErr;
 
     impl From<SuErr> for PyErr {
         fn from(e: SuErr) -> Self {
             match e {
-                SuErr::UnsupportedVariant => PyTypeError::new_err(
-                    "this variant is not supported on this operation"
-                ),
-                SuErr::ExceedMaxPrecision => PyOverflowError::new_err("the precision exceeded limit during the operation")
+                SuErr::UnsupportedVariant => {
+                    PyTypeError::new_err("this variant is not supported on this operation")
+                }
+                SuErr::ExceedMaxPrecision => {
+                    PyOverflowError::new_err("the precision exceeded limit during the operation")
+                }
             }
         }
     }
